@@ -121,6 +121,7 @@ OC.L10N.register(
     "Undo" : "撤消",
     "Deleted cards" : "已删除卡片",
     "Share board with a user, group or circle …" : "与一个用户，群组或圈子共享面板...",
+    "No participants found" : "未找到参与者",
     "Board owner" : "面板拥有者",
     "(Group)" : "（群组）",
     "(Circle)" : "（圈子）",
@@ -141,6 +142,11 @@ OC.L10N.register(
     "Add this attachment" : "添加此附件",
     "Delete Attachment" : "删除附件",
     "Restore Attachment" : "恢复附件",
+    "Attachments" : "附件",
+    "Comments" : "评论",
+    "Modified" : "已修改",
+    "Created" : "已创建",
+    "No comments yet. Begin the discussion!" : "还没有评论。 开始讨论吧！",
     "Assign a tag to this card…" : "为该卡片分配标签…",
     "Assign to users" : "指派给用户",
     "Assign to users/groups/circles" : "分配给用户/群组/圈子",
@@ -148,6 +154,13 @@ OC.L10N.register(
     "Due date" : "截至日期",
     "Set a due date" : "设置一个截止日期",
     "Remove due date" : "移除截至日期",
+    "Select Date" : "选择日期",
+    "Save" : "保存",
+    "The comment cannot be empty." : "注释不能为空。",
+    "The comment cannot be longer than 1000 characters." : "注释不能超过 1000 个字符。",
+    "In reply to" : "回复",
+    "Reply" : "回复",
+    "Update" : "更新",
     "Description" : "描述",
     "(Unsaved)" : "（未保存的）",
     "(Saving…)" : "（正在保存...）",
@@ -155,26 +168,14 @@ OC.L10N.register(
     "Edit description" : "编辑描述",
     "View description" : "查看描述",
     "Add Attachment" : "添加附件",
-    "Attachments" : "附件",
-    "Comments" : "评论",
     "Choose attachment" : "选择附件",
-    "Select Date" : "选择日期",
-    "Modified" : "已修改",
-    "Created" : "已创建",
-    "No comments yet. Begin the discussion!" : "还没有评论。 开始讨论吧！",
-    "Save" : "保存",
-    "The comment cannot be empty." : "注释不能为空。",
-    "The comment cannot be longer than 1000 characters." : "注释不能超过 1000 个字符。",
-    "In reply to" : "回复",
-    "Reply" : "回复",
-    "Update" : "更新",
     "(group)" : "（组）",
     "(circle)" : "（圈子）",
     "Assign to me" : "指派给我",
+    "Move card" : "移动卡片",
     "Unarchive card" : "恢复卡片存档",
     "Archive card" : "归档卡片",
     "Delete card" : "删除卡片",
-    "Move card" : "移动卡片",
     "Move card to another board" : "将卡片移到其他面板",
     "seconds ago" : "几秒前",
     "All boards" : "全部面板",
@@ -182,12 +183,8 @@ OC.L10N.register(
     "Shared with you" : "收到的共享",
     "Limit deck usage of groups" : "限制群组的看板使用",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "非面板创建用户组的用户将不能使用受限看板。但用户仍然能够使用已共享给他们的面板工作。",
-    "Edit board" : "编辑面板",
-    "Clone board " : "克隆面板",
-    "Unarchive board " : "解除面板归档",
-    "Archive board " : "面板归档",
-    "Delete board " : "删除面板",
     "Board details" : "面板详情",
+    "Edit board" : "编辑面板",
     "Board {0} deleted" : "面板{0} 被删除",
     "An error occurred" : "发生错误",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你确定你要删除 {title}面板吗？面板内所有数据都将因此被删除。",
