@@ -1,10 +1,9 @@
 const webpackConfig = require('@nextcloud/webpack-vue-config')
-const path = require('path');
+const path = require('path')
 const { merge } = require('webpack-merge')
 
 const config = {
 	entry: {
-		deck: path.join(__dirname, 'src', 'main.js'),
 		collections: path.join(__dirname, 'src', 'init-collections.js'),
 		dashboard: path.join(__dirname, 'src', 'init-dashboard.js'),
 	},
@@ -17,10 +16,9 @@ const config = {
 		extensions: ['*', '.js', '.vue', '.json'],
 		modules: [
 			path.resolve(__dirname, 'node_modules'),
-			'node_modules'
-		]
-	}
-};
+			'node_modules',
+		],
+	},
+}
 
 module.exports = merge(webpackConfig, config)
-
